@@ -524,7 +524,7 @@ class LSldapObject {
           // Validation par fonction externe
           else if(isset($test['function'])) {
             if (function_exists($test['function'])) {
-              if(!$test['function']($this)) {
+              if(!call_user_func_array($test['function'],array(&$this))) {
                 if ($LSform) $LSform -> setElementError($attr,$msg_error);
                 $retval = false;
               }
@@ -1106,38 +1106,22 @@ class LSldapObject {
    */
   function updateLSrelationsCache() {
     $this -> _LSrelationsCache=array();
-    if (is_array($this->config['LSrelation'])) {
+    if (is_array($this->config['LSrelation']) && LSsession :: loadLSclass('LSrelation')) {
       $type = $this -> getType();
       $me = new $type();
       $me -> loadData($this -> getDn());
       foreach($this->config['LSrelation'] as $relation_name => $relation_conf) {
-        if ( isset($relation_conf['list_function']) ) {
-          if (LSsession :: loadLSobject($relation_conf['LSobject'])) {
-            $obj = new $relation_conf['LSobject']();
-            if ((method_exists($obj,$relation_conf['list_function']))&&(method_exists($obj,$relation_conf['getkeyvalue_function']))) {
-              $list = $obj -> $relation_conf['list_function']($me);
-              if (is_array($list)) {
-                // Key Value
-                $key = $obj -> $relation_conf['getkeyvalue_function']($me);
-                
-                $this -> _LSrelationsCache[$relation_name] = array(
-                  'list' => $list,
-                  'keyvalue' => $key
-                );
-              }
-              else {
-                LSdebug('Problème durant la mise en cache de la relation '.$relation_name);
-                return;
-              }
-            }
-            else {
-              LSdebug('Les méthodes de mise en cache de la relation '.$relation_name. ' ne sont pas toutes disponibles.');
-              return;
-            }
-          }
-          else {
-            return;
-          }
+        $relation = new LSrelation($me, $relation_name);
+        $list = $relation -> listRelatedObjects();
+        if (is_array($list)) {
+          $this -> _LSrelationsCache[$relation_name] = array(
+            'list' => $list,
+            'keyvalue' => $relation -> getRelatedKeyValue()
+          );
+        }
+        else {
+          LSdebug('Problème durant la mise en cache de la relation '.$relation_name);
+          return;
         }
       }
     }
@@ -1177,15 +1161,10 @@ class LSldapObject {
     
     // LSrelations
     foreach($this -> _LSrelationsCache as $relation_name => $objInfos) {
-      if ((isset($this->config['LSrelation'][$relation_name]['rename_function']))&&(is_array($objInfos['list']))) {
+      $relation = new LSrelation($this, $relation_name);
+      if (is_array($objInfos['list'])) {
         foreach($objInfos['list'] as $obj) {
-          $meth = $this->config['LSrelation'][$relation_name]['rename_function'];
-          if (method_exists($obj,$meth)) {
-            if (!($obj -> $meth($this,$objInfos['keyvalue']))) {
-              $error=1;
-            }
-          }
-          else {
+          if (!$relation -> renameRelationWithObject($obj, $objInfos['keyvalue'])) {
             $error=1;
           }
         }
@@ -1229,17 +1208,13 @@ class LSldapObject {
     
     // LSrelations
     foreach($this -> _LSrelationsCache as $relation_name => $objInfos) {
-      if ((isset($this->config['LSrelation'][$relation_name]['remove_function']))&&(is_array($objInfos['list']))) {
+      $relation = new LSrelation($this, $relation_name);
+      if (is_array($objInfos['list'])) {
         foreach($objInfos['list'] as $obj) {
-          $meth = $this->config['LSrelation'][$relation_name]['remove_function'];
-          if (method_exists($obj,$meth)) {
-            if (!($obj -> $meth($this))) {
-              $error=1;
-            }
-          }
-          else {
-            $error=1;
+          if (!$relation -> canEditRelationWithObject($obj)) {
+            LSerror :: addErrorCode('LSsession_11');
           }
+          elseif (!$relation -> removeRelationWithObject($obj)) $error=1;
         }
       }
     }
@@ -1332,25 +1307,31 @@ class LSldapObject {
    * 
    * @param[in] $object Un object de type $objectType
    * @param[in] $objectType Le type d'objet en relation
-   * @param[in] $value La valeur que doit avoir l'attribut :
-   *                      - soit le dn (par defaut)
-   *                      - soit la valeur [0] d'un attribut
+   * @param[in] $attrValues La/les valeur(s) que doit/peut avoir l'attribut :
+   *                        - soit le dn (par defaut)
+   *                        - soit une des valeurs d'un attribut
    * 
    * @retval Mixed La valeur clef d'un objet en relation
    **/
-  function getObjectKeyValueInRelation($object,$objectType,$attrValue='dn') {
+  function getObjectKeyValueInRelation($object,$objectType,$attrValues='dn') {
     if (!$objectType) {
       LSerror :: addErrorCode('LSrelations_05','getObjectKeyValueInRelation');
       return;
     }
-    if ($attrValue=='dn') {
-      $val = $object -> getDn();
+    if (!is_array($attrValues)) $attrValues=array($attrValues);
+    $keyValues=array();
+    foreach ($attrValues as $attrValue) {
+      if ($attrValue=='dn') {
+        $dn=$object -> getDn();
+        if (!in_array($dn,$keyValues))
+          $keyValues[] = $dn;
+      }
+      else {
+        foreach ($object -> getValue($attrValue) as $keyValue)
+          if (!in_array($keyValue,$keyValues)) $keyValues[]=$keyValue;
+      }
     }
-    else {
-      $val = $object -> getValue($attrValue);
-      $val = $val[0];
-    }
-    return $val;
+    return $keyValues;
   }
   
   /**
@@ -1365,29 +1346,29 @@ class LSldapObject {
    * @param[in] $object Un object de type $objectType
    * @param[in] $attr L'attribut dans lequel l'objet doit apparaitre
    * @param[in] $objectType Le type d'objet en relation
-   * @param[in] $value La valeur que doit avoir l'attribut :
+   * @param[in] $attrValues La/les valeur(s) que doit/peut avoir l'attribut :
    *                      - soit le dn (par defaut)
-   *                      - soit la valeur [0] d'un attribut
+   *                      - soit une des valeurs d'un attribut
    * 
    * @retval Array of $objectType Les objets en relations
    **/
-  function listObjectsInRelation($object,$attr,$objectType,$attrValue='dn') {
+  function listObjectsInRelation($object,$attr,$objectType,$attrValues='dn') {
     if ((!$attr)||(!$objectType)) {
       LSerror :: addErrorCode('LSrelations_05','listObjectsInRelation');
       return;
     }
-    if ($attrValue=='dn') {
-      $val = $object -> getDn();
-    }
-    else {
-      $val = $object -> getValue($attrValue);
-      $val = $val[0];
-    }
-    if ($val) {
-      $filter = Net_LDAP2_Filter::create($attr,'equals',$val);
+    if (!is_array($attrValues)) $attrValues=array($attrValues);
+    $keyValues=self :: getObjectKeyValueInRelation($object,$objectType,$attrValues);
+    if (!empty($keyValues)) {
+      $keyValuesFilters=array();
+      foreach($keyValues as $keyValue) {
+        $keyValuesFilters[] = Net_LDAP2_Filter::create($attr,'equals',$keyValue);
+      }
+      $filter = LSldap::combineFilters('or', $keyValuesFilters);
       return $this -> listObjects($filter,LSsession :: getRootDn(),array('scope' => 'sub','recursive' => true,'withoutCache'=>true, 'onlyAccessible' => false));
     }
-    return;
+
+    return array();
   }
 
   /**
@@ -1416,6 +1397,10 @@ class LSldapObject {
           return;
         }
       }
+      elseif (!LSsession::canEdit($this -> getType(), $this -> getDn(), $attr)) {
+        LSerror :: addErrorCode('LSsession_11');
+        return;
+      }
       if ($this -> attrs[$attr] instanceof LSattribute) {
         if ($attrValue=='dn') {
           $val = $object -> getDn();
@@ -1459,10 +1444,13 @@ class LSldapObject {
    *                      - soit la valeur [0] d'un attribut
    * @param[in] $canEditFunction  Le nom de la fonction pour vérifier que la
    *                              relation avec l'objet est éditable par le user
+   * @param[in] $attrValues L'ensembe des valeurs que peut avoir l'attribut avant mise à jour :
+   *                        - soit le dn (par defaut)
+   *                        - soit une des valeurs d'un attribut
    * 
    * @retval boolean true si l'objet à été supprimé, False sinon
    **/  
-  function deleteOneObjectInRelation($object,$attr,$objectType,$attrValue='dn',$canEditFunction=NULL) {
+  function deleteOneObjectInRelation($object,$attr,$objectType,$attrValue='dn',$canEditFunction=NULL,$attrValues=null) {
     if ((!$attr)||(!$objectType)) {
       LSerror :: addErrorCode('LSrelations_05','deleteOneObjectInRelation');
       return;
@@ -1474,14 +1462,13 @@ class LSldapObject {
           return;
         }
       }
+      elseif (!LSsession::canEdit($this -> getType(), $this -> getDn(), $attr)) {
+        LSerror :: addErrorCode('LSsession_11');
+        return;
+      }
       if ($this -> attrs[$attr] instanceof LSattribute) {
-        if ($attrValue=='dn') {
-          $val = $object -> getDn();
-        }
-        else {
-          $val = $object -> getValue($attrValue);
-          $val = $val[0];
-        }
+        if (!is_array($attrValues)) $attrValues=array($attrValue);
+        $keyValues=self :: getObjectKeyValueInRelation($object,$objectType,$attrValues);
         $values = $this -> attrs[$attr] -> getValue();
         if ((!is_array($values)) && (!empty($values))) {
           $values = array($values);
@@ -1489,7 +1476,7 @@ class LSldapObject {
         if (is_array($values)) {
           $updateData=array();
           foreach($values as $value) {
-            if ($value!=$val) {
+            if (!in_array($value,$keyValues)) {
               $updateData[]=$value;
             }
           }
@@ -1504,7 +1491,8 @@ class LSldapObject {
   * Renome un objet en relation dans l'attribut $attr de $this
   * 
   * @param[in] $object Un objet de type $objectType à renomer
-  * @param[in] $oldValue string L'ancienne valeur faisant référence à l'objet
+  * @param[in] $oldValues array|string Le(s) ancienne(s) valeur(s possible(s)
+  *                                    faisant référence à l'objet
   * @param[in] $attr L'attribut dans lequel l'objet doit être supprimé
   * @param[in] $objectType Le type d'objet en relation
   * @param[in] $attrValue La valeur que doit avoir l'attribut :
@@ -1513,11 +1501,12 @@ class LSldapObject {
   *  
   * @retval boolean True en cas de succès, False sinon
   */
-  function renameOneObjectInRelation($object,$oldValue,$attr,$objectType,$attrValue='dn') {
+  function renameOneObjectInRelation($object,$oldValues,$attr,$objectType,$attrValue='dn') {
     if ((!$attr)||(!$objectType)) {
       LSerror :: addErrorCode('LSrelations_05','renameOneObjectInRelation');
       return;
     }
+    if (!is_array($oldValues)) $oldValues=array($oldValues);
     if ($object instanceof $objectType) {
       if ($this -> attrs[$attr] instanceof LSattribute) {
         $values = $this -> attrs[$attr] -> getValue();
@@ -1527,7 +1516,7 @@ class LSldapObject {
         if (is_array($values)) {
           $updateData=array();
           foreach($values as $value) {
-            if ($value!=$oldValue) {
+            if (!in_array($value,$oldValues)) {
               $updateData[] = $value;
             }
             else {
@@ -1562,94 +1551,48 @@ class LSldapObject {
    *                      - soit la valeur [0] d'un attribut
    * @param[in] $canEditFunction  Le nom de la fonction pour vérifier que la
    *                              relation avec l'objet est éditable par le user
+   * @param[in] $attrValues L'ensembe des valeurs que peut avoir l'attribut avant mise à jour :
+   *                        - soit le dn (par defaut)
+   *                        - soit une des valeurs d'un attribut
    * 
    * @retval boolean true si tout c'est bien passé, False sinon
    **/  
-  function updateObjectsInRelation($object,$listDns,$attr,$objectType,$attrValue='dn',$canEditFunction=NULL) {
+  function updateObjectsInRelation($object,$listDns,$attr,$objectType,$attrValue='dn',$canEditFunction=NULL,$attrValues=null) {
     if ((!$attr)||(!$objectType)) {
       LSerror :: addErrorCode('LSrelations_05','updateObjectsInRelation');
       return;
     }
-    $currentObjects = $this -> listObjectsInRelation($object,$attr,$objectType,$attrValue);
-    $type=$this -> getType();
+    if (!is_array($attrValues)) $attrValues=array($attrValue);
+    $currentDns=array();
+    $currentObjects = $this -> listObjectsInRelation($object,$attr,$objectType,$attrValues);
     if(is_array($currentObjects)) {
-      if (is_array($listDns)) {
-        $values=array();
-        if ($attrValue!='dn') {
-          $obj=new $objectType();
-          foreach ($listDns as $dn) {
-            $obj -> loadData($dn);
-            $val = $obj -> getValue($attrValue);
-            $values[$dn] = $val[0];
-          }
-        }
-        else {
-          foreach($listDns as $dn) {
-            $values[$dn] = $dn;
-          }
-        }
-        $dontDelete=array();
-        $dontAdd=array();
-        for ($i=0;$i<count($currentObjects);$i++) {
-          if ($attrValue=='dn') {
-            $val = $currentObjects[$i] -> getDn();
-          }
-          else {
-            $val = $currentObjects[$i] -> getValue($attrValue);
-            $val = $val[0];
-          }
-          if (in_array($val, $listDns)) {
-            $dontDelete[$i]=true;
-            $dontAdd[]=$val;
-          }
-        }
-        
-        for($i=0;$i<count($currentObjects);$i++) {
-          if ($dontDelete[$i]) {
-            continue;
-          }
-          else {
-            if (!$currentObjects[$i] -> deleteOneObjectInRelation($object,$attr,$objectType,$attrValue,$canEditFunction)) {
-              return;
-            }
-          }
-        }
-        
-        foreach($values as $dn => $val) {
-          if (in_array($val,$dontAdd)) {
-            continue;
-          }
-          else {
-            $obj = new $type();
-            if ($obj -> loadData($dn)) {
-              if (!$obj -> addOneObjectInRelation($object,$attr,$objectType,$attrValue,$canEditFunction)) {
-                return;
-              }
-            }
-            else {
-              return;
-            }
-          }
-        }
-        return true;
+      for ($i=0;$i<count($currentObjects);$i++) {
+        $currentDns[]=$currentObjects[$i] -> getDn();
       }
     }
-    else {
-      if(!is_array($listDns)) {
-        return true;
+    $dontTouch=array_intersect($listDns,$currentDns);
+
+    for($i=0;$i<count($currentObjects);$i++) {
+      if (in_array($currentObjects[$i] -> getDn(),$dontTouch)) continue;
+      if (!$currentObjects[$i] -> deleteOneObjectInRelation($object,$attr,$objectType,$attrValue,$canEditFunction,$attrValues)) {
+        return;
       }
-      foreach($listDns as $dn) {
-        $obj = new $type();
-        if ($obj -> loadData($dn)) {
-          if (!$obj -> addOneObjectInRelation($object,$attr,$objectType,$attrValue,$canEditFunction)) {
-            return;
-          }
-        }
-        else {
+    }
+
+    $type=$this -> getType();
+    foreach($listDns as $dn) {
+      if (in_array($dn,$dontTouch)) continue;
+      $obj = new $type();
+      if ($obj -> loadData($dn)) {
+        if (!$obj -> addOneObjectInRelation($object,$attr,$objectType,$attrValue,$canEditFunction)) {
           return;
         }
       }
+      else {
+        return;
+      }
     }
+    return true;
   }
   
   /**
@@ -1710,7 +1653,7 @@ class LSldapObject {
       }
       foreach($funcs as $func) {
         if(function_exists($func)) {
-          if(!$func($this)) {
+          if(!call_user_func_array($func,array(&$this))) {
             $return = false;
             LSerror :: addErrorCode('LSldapObject_07',array('func' => $func,'event' => $event));
           }
@@ -1730,7 +1673,7 @@ class LSldapObject {
             $obj = new $e['class']();
             if (method_exists($obj,$e['fct'])) {
               try {
-                $obj -> $e['fct']($e['param']);
+                call_user_func_array(array($obj,$e['fct']),array(&$e['param']));
               }
               catch(Exception $er) {
                 LSerror :: addErrorCode('LSldapObject_10',array('class' => $e['class'],'meth' => $e['fct'],'event' => $event));
@@ -1750,7 +1693,7 @@ class LSldapObject {
         else {
           if (function_exists($e['fct'])) {
             try {
-              $e['fct']($e['param']);
+              call_user_func_array($e['fct'],array(&$e['param']));
             }
             catch(Exception $er) {
               LSerror :: addErrorCode('LSldapObject_27',array('func' => $e['fct'],'event' => $event));
@@ -1770,7 +1713,7 @@ class LSldapObject {
       foreach ($this -> _objectEvents[$event] as $e) {
         if (method_exists($e['obj'],$e['meth'])) {
           try {
-            $e['obj'] -> $e['meth']($e['param']);
+            call_user_func_array(array($e['obj'], $e['meth']),array(&$e['param']));
           }
           catch(Exception $er) {
             LSerror :: addErrorCode('LSldapObject_29',array('meth' => $e['meth'],'event' => $event));
