@@ -670,13 +670,14 @@ class LSsession {
           'equals',
           $recoveryHash
         );
-        $result = $authobject -> listObjects($filter,self :: $topDn);
+        $result = $authobject -> listObjects($filter,self :: $topDn,array('onlyAccessible' => false));
       }
       elseif (!empty($username)) {
         $result = $authobject -> searchObject(
                     $username,
                     self :: $topDn,
-                    self :: $ldapServer['authObjectFilter']
+                    self :: $ldapServer['authObjectFilter'],
+                    array('onlyAccessible' => false)
                   );
       }
       else {
@@ -1062,9 +1063,11 @@ class LSsession {
             else {
               $displayName = NULL;
             }
+            $sparams = array();
+            $sparams['onlyAccessible'] = (isset($LSoject_config['onlyAccessible'])?$LSoject_config['onlyAccessible']:False);
             if( self :: loadLSobject($LSobject_name) ) {
               if ($subdnobject = new $LSobject_name()) {
-                $tbl_return = $subdnobject -> getSelectArray(NULL,$basedn,$displayName);
+                $tbl_return = $subdnobject -> getSelectArray(NULL,$basedn,$displayName,false,false,NULL,$sparams);
                 if (is_array($tbl_return)) {
                   $return=array_merge($return,$tbl_return);
                 }
@@ -1555,6 +1558,7 @@ class LSsession {
     $params = array(
       'basedn' => isset($filter_def['basedn']) ? $filter_def['basedn'] : $basedn,
       'filter' => $filter,
+      'onlyAccessible' => False
     );
     if (isset($filter_def['params']) && is_array($filter_def['params'])) {
       $params = array_merge($filter_def['params'],$params);
@@ -1703,7 +1707,7 @@ class LSsession {
             foreach($config as $objectType => $objectConf) {
               if (self :: loadLSobject($objectType)) {
                 if ($subdnobject = new $objectType()) {
-                  $tbl = $subdnobject -> getSelectArray(NULL,self::getRootDn(),NULL,NULL,false);
+                  $tbl = $subdnobject -> getSelectArray(NULL,self::getRootDn(),NULL,NULL,false,NULL,array('onlyAccessible' => False));
                   if (is_array($tbl)) {
                     // Définition des accès
                     $access=array();
